package
Version:
v0.5.3
Opens a new window with list of versions in this module.
Published: Oct 19, 2025
License: MIT
Opens a new window with license information.
Imports: 21
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Execute runs the root command
func SetVersionInfo(v, c, d, b string)
SetVersionInfo sets version information from main package
Source Files
¶
Click to show internal directories.
Click to hide internal directories.