Documentation
¶
Index ¶
- func CloneRepository(repoURL, destDir string) (string, error)
- func CloneRepositoryWithBranch(repoURL, branch, destDir string) error
- func GetRepositoryInfo(repoPath string) (map[string]string, error)
- func IsGitHubURL(s string) bool
- func IsGitRepository(path string) bool
- func IsZipFile(path string) bool
- type Analyzer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CloneRepository ¶
CloneRepository clones a Git repository to the specified destination and returns the commit SHA
func CloneRepositoryWithBranch ¶
CloneRepositoryWithBranch clones a specific branch of a Git repository
func GetRepositoryInfo ¶
GetRepositoryInfo extracts repository information
func IsGitRepository ¶
IsGitRepository checks if a directory is a Git repository
Types ¶
Click to show internal directories.
Click to hide internal directories.