Documentation
¶
Index ¶
- func GetApplicationURL(ctx context.Context, asgName, region string, port int, verbose bool) (string, error)
- func ParsePort(portStr string) (int, error)
- func WaitForApplicationReady(ctx context.Context, url string, timeout time.Duration, verbose bool) error
- type DeployConfig
- type Deployer
- type InstanceInfo
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetApplicationURL ¶
func GetApplicationURL(ctx context.Context, asgName, region string, port int, verbose bool) (string, error)
GetApplicationURL constructs the application URL and waits for it to be ready
Types ¶
type DeployConfig ¶
type DeployConfig struct {
Strategy string
Analysis *types.Analysis
UserPrompt string
WorkDir string
AWSRegion string
TerraformBin string
Verbose bool
// LLM information
LLMProvider string
LLMModel string
// EC2 sizing
EC2InstanceType string
EC2VolumeSize int
// Lambda sizing
LambdaMemory int
LambdaTimeout int
LambdaReservedConcurrency int
// EKS sizing
EKSNodeType string
EKSMinNodes int
EKSMaxNodes int
EKSDesiredNodes int
EKSNodeVolumeSize int
}
DeployConfig contains deployment configuration
type Deployer ¶
type Deployer struct {
// contains filtered or unexported fields
}
Deployer orchestrates the deployment process
func NewDeployer ¶
func NewDeployer(config *DeployConfig, storeInstance store.Store) *Deployer
NewDeployer creates a new Deployer instance
func (*Deployer) Deploy ¶
func (d *Deployer) Deploy() (*types.DeploymentResult, error)
Deploy executes the deployment workflow
func (*Deployer) SetLLMClient ¶
SetLLMClient sets the LLM client for the deployer
type InstanceInfo ¶
InstanceInfo contains information about an EC2 instance
func GetASGInstance ¶
func GetASGInstance(ctx context.Context, asgName, region string, verbose bool) (*InstanceInfo, error)
GetASGInstance retrieves the public IP of the first running instance in an ASG
func WaitForASGInstance ¶
func WaitForASGInstance(ctx context.Context, asgName, region string, timeout time.Duration, verbose bool) (*InstanceInfo, error)
WaitForASGInstance waits for an instance to be running in the ASG
Click to show internal directories.
Click to hide internal directories.