Documentation
¶
Index ¶
- func ConfirmDeployment(plan *DeploymentPlan, skipConfirmation bool) (bool, error)
- func ConfirmOrModify(plan *DeploymentPlan, analysis *types.Analysis, config *deployer.DeployConfig, ...) (bool, *deployer.DeployConfig, error)
- func DisplayPlanTable(plan *DeploymentPlan) error
- type DeploymentPlan
- type ResourceConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConfirmDeployment ¶
func ConfirmDeployment(plan *DeploymentPlan, skipConfirmation bool) (bool, error)
ConfirmDeployment displays the deployment plan and prompts for confirmation Returns: confirmed (bool), error
func ConfirmOrModify ¶
func ConfirmOrModify(plan *DeploymentPlan, analysis *types.Analysis, config *deployer.DeployConfig, llmClient *llm.Client, autoApprove bool) (bool, *deployer.DeployConfig, error)
ConfirmOrModify shows the plan and allows confirmation or modification
func DisplayPlanTable ¶
func DisplayPlanTable(plan *DeploymentPlan) error
DisplayPlanTable renders a beautiful table showing the deployment plan
Types ¶
type DeploymentPlan ¶
type DeploymentPlan struct {
Strategy string
Region string
AppName string
Resources []ResourceConfig
}
DeploymentPlan represents the complete deployment plan
func BuildDeploymentPlan ¶
func BuildDeploymentPlan(strategy, region, appName string, analysis *types.Analysis, config *deployer.DeployConfig) *DeploymentPlan
BuildDeploymentPlan creates a deployment plan based on the strategy and configuration
type ResourceConfig ¶
type ResourceConfig struct {
Type string // Resource type (e.g., "VPC", "EC2 Instance", "EKS Cluster")
Name string // Resource name
Parameters map[string]string // Configuration parameters
Important bool // Highlight important resources
}
ResourceConfig represents a single resource to be created
func (*ResourceConfig) AddParameter ¶
func (r *ResourceConfig) AddParameter(key, value string)
Add a parameter to a resource
Click to show internal directories.
Click to hide internal directories.